==> haskell-hspec-golden-0.2.1.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-CKQ6RxsiRAl1cbaEsinlV3
key:                  hspec-golden-0.2.1.0-CKQ6RxsiRAl1cbaEsinlV3
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  9a482b6b32c9f4572dfc19617e7b3134
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-CKQ6RxsiRAl1cbaEsinlV3
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    hspec-core-2.10.9-7yO45d4zctM4pxLO6U8zpB

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-golden-0.2.1.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-64cFdhtLn7u8nDWrZ8pk5x
key:                  hspec-golden-0.2.1.0-64cFdhtLn7u8nDWrZ8pk5x
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  055dc530f7ae563283482f579c44faef
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-64cFdhtLn7u8nDWrZ8pk5x
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    hspec-core-2.10.9-46iY0XuXwGZ2OnLkFKtXTW

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
